import { Chain, Network, PlatformToChains } from "@wormhole-foundation/sdk-base";
import { Platform } from "@wormhole-foundation/sdk-base/dist/cjs";
import { ChainContext, Signer, TokenBridge, TokenId, TransactionId, TxHash, WormholeMessageId } from "@wormhole-foundation/sdk-definitions";
import { TokenTransferDetails } from "../types";
import { Wormhole } from "../wormhole";
import { AttestationId, TransferQuote, TransferState, WormholeTransfer } from "../wormholeTransfer";
export declare class TokenTransfer<N extends Network> implements WormholeTransfer {
    private readonly wh;
    private state;
    transfer: TokenTransferDetails;
    txids: TransactionId[];
    vaas?: {
        id: WormholeMessageId;
        vaa?: TokenBridge.VAA<"Transfer" | "TransferWithPayload">;
    }[];
    private constructor();
    getTransferState(): Promise<TransferState>;
    static from<N extends Network>(wh: Wormhole<N>, from: TokenTransferDetails): Promise<TokenTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: WormholeMessageId, timeout?: number): Promise<TokenTransfer<N>>;
    static from<N extends Network>(wh: Wormhole<N>, from: TransactionId, timeout?: number): Promise<TokenTransfer<N>>;
    private static fromIdentifier;
    private static fromTransaction;
    initiateTransfer(signer: Signer): Promise<TxHash[]>;
    fetchAttestation(timeout?: number): Promise<AttestationId[]>;
    completeTransfer(signer: Signer): Promise<TxHash[]>;
    static transfer<N extends Network>(fromChain: ChainContext<N, Platform, Chain>, transfer: TokenTransferDetails, signer: Signer<N, Chain>): Promise<TransactionId[]>;
    static redeem<N extends Network>(toChain: ChainContext<N, Platform, Chain>, vaa: TokenBridge.VAA<"Transfer" | "TransferWithPayload">, signer: Signer<N, Chain>, automatic?: boolean): Promise<TransactionId[]>;
    static isTransferComplete<N extends Network, P extends Platform, C extends PlatformToChains<P>>(toChain: ChainContext<N, P, C>, vaa: TokenBridge.VAA<"Transfer" | "TransferWithPayload">): Promise<boolean>;
    static getTransferMessage<N extends Network, P extends Platform, C extends PlatformToChains<P>>(chain: ChainContext<N, P, C>, txid: TxHash, timeout?: number): Promise<WormholeMessageId>;
    static getTransferVaa<N extends Network>(wh: Wormhole<N>, key: WormholeMessageId | TxHash, timeout?: number): Promise<TokenBridge.VAA<"Transfer" | "TransferWithPayload">>;
    static lookupDestinationToken<N extends Network>(srcChain: ChainContext<N, Platform, Chain>, dstChain: ChainContext<N, Platform, Chain>, transfer: TokenTransferDetails): Promise<TokenId>;
    static isAutomatic<N extends Network>(wh: Wormhole<N>, vaa: TokenBridge.VAA<"Transfer" | "TransferWithPayload">): boolean;
    static validateTransferDetails<N extends Network>(wh: Wormhole<N>, transfer: TokenTransferDetails): Promise<void>;
    static quoteTransfer<N extends Network>(srcChain: ChainContext<N, Platform, Chain>, dstChain: ChainContext<N, Platform, Chain>, transfer: TokenTransferDetails): Promise<TransferQuote>;
    static destinationOverrides<N extends Network>(srcChain: ChainContext<N, Platform, Chain>, dstChain: ChainContext<N, Platform, Chain>, transfer: TokenTransferDetails): Promise<TokenTransferDetails>;
}
//# sourceMappingURL=tokenTransfer.d.ts.map